=== modified file 'bzrlib/inventory_delta.py'
--- bzrlib/inventory_delta.py	2009-08-03 06:22:43 +0000
+++ bzrlib/inventory_delta.py	2009-08-04 00:51:24 +0000
@@ -354,7 +354,9 @@
         'tree': _tree_to_entry,
     }
     kind = content[0]
-    path = utf8_path[1:].decode('utf8')
+    if utf8_path.startswith('/'):
+        raise AssertionError
+    path = utf8_path.decode('utf8')
     name = basename(path)
     return entry_factory[content[0]](
             content, name, parent_id, file_id, last_modified)

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2009-07-31 08:34:13 +0000
+++ bzrlib/repository.py	2009-08-04 00:51:24 +0000
@@ -3972,7 +3972,6 @@
                 pass
             else:
                 new_pack.set_write_cache_size(1024*1024)
-        delta_deserializer = inventory_delta.InventoryDeltaSerializer()
         for substream_type, substream in stream:
             if substream_type == 'texts':
                 self.target_repo.texts.insert_record_stream(substream)
@@ -3982,8 +3981,10 @@
                         substream)
                 else:
                     self._extract_and_insert_inventories(
-                        substream, src_serializer,
-                        delta_deserializer.parse_text_bytes)
+                        substream, src_serializer)
+            elif substream_type == 'inventory-deltas':
+                self._extract_and_insert_inventory_deltas(
+                    substream, src_serializer)
             elif substream_type == 'chk_bytes':
                 # XXX: This doesn't support conversions, as it assumes the
                 #      conversion was done in the fetch code.
@@ -4040,6 +4041,27 @@
             self.target_repo.pack(hint=hint)
         return [], set()
 
+    def _extract_and_insert_inventory_deltas(self, substream, serializer):
+        target_rich_root = self.target_repo._format.rich_root_data
+        target_tree_refs = self.target_repo._format.supports_tree_reference
+        for record in substream:
+            # Insert the delta directly
+            inventory_delta_bytes = record.get_bytes_as('fulltext')
+            deserialiser = inventory_delta.InventoryDeltaSerializer()
+            parse_result = deserialiser.parse_text_bytes(inventory_delta_bytes)
+            basis_id, new_id, rich_root, tree_refs, inv_delta = parse_result
+            #mutter('inv_delta: %r', inv_delta)
+            # Make sure the delta is compatible with the target
+            if rich_root and not target_rich_root:
+                raise errors.IncompatibleRevision(self.target_repo._format)
+            if tree_refs and not target_tree_refs:
+                raise errors.IncompatibleRevision(self.target_repo._format)
+            #revision_id = new_id[0]
+            revision_id = new_id
+            parents = [key[0] for key in record.parents]
+            self.target_repo.add_inventory_by_delta(
+                basis_id, inv_delta, revision_id, parents)
+
     def _extract_and_insert_inventories(self, substream, serializer,
             parse_delta=None):
         """Generate a new inventory versionedfile in target, converting data.
@@ -4050,20 +4072,6 @@
         target_rich_root = self.target_repo._format.rich_root_data
         target_tree_refs = self.target_repo._format.supports_tree_reference
         for record in substream:
-            if record.storage_kind == 'inventory-delta':
-                # Insert the delta directly
-                delta_tuple = record.get_bytes_as('inventory-delta')
-                basis_id, new_id, inv_delta, format_flags = delta_tuple
-                # Make sure the delta is compatible with the target
-                if format_flags[0] and not target_rich_root:
-                    raise errors.IncompatibleRevision(self.target_repo._format)
-                if format_flags[1] and not target_tree_refs:
-                    raise errors.IncompatibleRevision(self.target_repo._format)
-                revision_id = new_id[0]
-                parents = [key[0] for key in record.parents]
-                self.target_repo.add_inventory_by_delta(
-                    basis_id, inv_delta, revision_id, parents)
-                continue
             # It's not a delta, so it must be a fulltext in the source
             # serializer's format.
             bytes = record.get_bytes_as('fulltext')
@@ -4211,6 +4219,8 @@
             if not keys:
                 # No need to stream something we don't have
                 continue
+            if substream_kind == 'inventory-deltas':
+                XXX
             if substream_kind == 'inventories':
                 # Some missing keys are genuinely ghosts, filter those out.
                 present = self.from_repository.inventories.get_parent_map(keys)
@@ -4278,7 +4288,7 @@
         # convert on the target, so we need to put bytes-on-the-wire that can
         # be converted.  That means inventory deltas (if the remote is <1.18,
         # RemoteStreamSink will fallback to VFS to insert the deltas).
-        yield ('inventories',
+        yield ('inventory-deltas',
            self._stream_invs_as_deltas(revision_ids,
                                        delta_versus_null=delta_versus_null))
 
@@ -4307,6 +4317,8 @@
         inventory_cache = lru_cache.LRUCache(50)
         null_inventory = from_repo.revision_tree(
             _mod_revision.NULL_REVISION).inventory
+        serializer = inventory_delta.InventoryDeltaSerializer()
+        serializer.require_flags(*flags)
         for inv in inventories:
             key = (inv.revision_id,)
             parent_keys = parent_map.get(key, ())
@@ -4339,8 +4351,10 @@
                 delta = inv._make_delta(null_inventory)
             invs_sent_so_far.add(inv.revision_id)
             inventory_cache[inv.revision_id] = inv
-            yield versionedfile.InventoryDeltaContentFactory(
-                key, parent_keys, None, delta, basis_id, flags, from_repo)
+            delta_serialized = ''.join(
+                serializer.delta_to_lines(basis_id, key[-1], delta))
+            yield versionedfile.FulltextContentFactory(
+                key, parent_keys, None, delta_serialized)
 
 
 def _iter_for_revno(repo, partial_history_cache, stop_index=None,

=== modified file 'bzrlib/smart/repository.py'
--- bzrlib/smart/repository.py	2009-07-15 06:40:06 +0000
+++ bzrlib/smart/repository.py	2009-08-04 00:51:24 +0000
@@ -43,7 +43,6 @@
 from bzrlib.versionedfile import (
     NetworkRecordStream,
     record_to_fulltext_bytes,
-    record_to_inventory_delta_bytes,
     )
 
 

=== modified file 'bzrlib/tests/test_inventory_delta.py'
--- bzrlib/tests/test_inventory_delta.py	2009-07-31 08:31:41 +0000
+++ bzrlib/tests/test_inventory_delta.py	2009-08-04 00:51:24 +0000
@@ -63,7 +63,6 @@
 /\x00an-id\x00\x00different-version\x00dir
 """
 
-# No root entry is included for unversioned roots.
 root_only_unversioned = """format: bzr inventory delta v1 (bzr 1.14)
 parent: null:
 version: entry-version
@@ -263,6 +262,24 @@
         err = self.assertRaises(errors.BzrError,
             serializer.parse_text_bytes, lines)
         self.assertContainsRe(str(err), 'oldpath invalid')
+    
+    def test_parse_new_file(self):
+        """a new file is parsed correctly"""
+        lines = root_only_lines
+        fake_sha = "deadbeef" * 5
+        lines += (
+            "None\x00/new\x00file-id\x00an-id\x00version\x00file\x00123\x00" +
+            "\x00" + fake_sha + "\n")
+        serializer = inventory_delta.InventoryDeltaSerializer()
+        parse_result = serializer.parse_text_bytes(lines)
+        expected_entry = inventory.make_entry(
+            'file', u'new', 'an-id', 'file-id')
+        expected_entry.revision = 'version'
+        expected_entry.text_size = 123
+        expected_entry.text_sha1 = fake_sha
+        delta = parse_result[4]
+        self.assertEqual(
+             (None, u'new', 'file-id', expected_entry), delta[-1])
 
 
 class TestSerialization(TestCase):

=== modified file 'bzrlib/versionedfile.py'
--- bzrlib/versionedfile.py	2009-07-31 08:34:13 +0000
+++ bzrlib/versionedfile.py	2009-08-04 00:51:24 +0000
@@ -160,31 +160,6 @@
             self.storage_kind)
 
 
-class InventoryDeltaContentFactory(ContentFactory):
-
-    def __init__(self, key, parents, sha1, delta, basis_id, format_flags,
-            repo=None):
-        self.sha1 = sha1
-        self.storage_kind = 'inventory-delta'
-        self.key = key
-        self.parents = parents
-        self._delta = delta
-        self._basis_id = basis_id
-        self._format_flags = format_flags
-        self._repo = repo
-
-    def get_bytes_as(self, storage_kind):
-        if storage_kind == self.storage_kind:
-            return self._basis_id, self.key, self._delta, self._format_flags
-        elif storage_kind == 'inventory-delta-bytes':
-            serializer = inventory_delta.InventoryDeltaSerializer()
-            serializer.require_flags(*self._format_flags)
-            return ''.join(serializer.delta_to_lines(
-                self._basis_id, self.key[-1], self._delta))
-        raise errors.UnavailableRepresentation(self.key, storage_kind,
-            self.storage_kind)
-
-
 class AbsentContentFactory(ContentFactory):
     """A placeholder content factory for unavailable texts.
 
@@ -1587,7 +1562,6 @@
         self._kind_factory = {
             'fulltext': fulltext_network_to_record,
             'groupcompress-block': groupcompress.network_block_to_records,
-            'inventory-delta': inventory_delta_network_to_record,
             'knit-ft-gz': knit.knit_network_to_record,
             'knit-delta-gz': knit.knit_network_to_record,
             'knit-annotated-ft-gz': knit.knit_network_to_record,
@@ -1618,21 +1592,6 @@
     return [FulltextContentFactory(key, parents, None, fulltext)]
 
 
-def inventory_delta_network_to_record(kind, bytes, line_end):
-    """Convert a network inventory-delta record to record."""
-    meta_len, = struct.unpack('!L', bytes[line_end:line_end+4])
-    record_meta = bytes[line_end+4:line_end+4+meta_len]
-    key, parents = bencode.bdecode_as_tuple(record_meta)
-    if parents == 'nil':
-        parents = None
-    inventory_delta_bytes = bytes[line_end+4+meta_len:]
-    deserialiser = inventory_delta.InventoryDeltaSerializer()
-    parse_result = deserialiser.parse_text_bytes(inventory_delta_bytes)
-    basis_id, new_id, rich_root, tree_refs, delta = parse_result
-    return [InventoryDeltaContentFactory(
-        key, parents, None, delta, basis_id, (rich_root, tree_refs))]
-
-
 def _length_prefix(bytes):
     return struct.pack('!L', len(bytes))
 
@@ -1648,17 +1607,6 @@
         _length_prefix(record_meta), record_meta, record_content)
 
 
-def record_to_inventory_delta_bytes(record):
-    record_content = record.get_bytes_as('inventory-delta-bytes')
-    if record.parents is None:
-        parents = 'nil'
-    else:
-        parents = record.parents
-    record_meta = bencode.bencode((record.key, parents))
-    return "inventory-delta\n%s%s%s" % (
-        _length_prefix(record_meta), record_meta, record_content)
-
-
 def sort_groupcompress(parent_map):
     """Sort and group the keys in parent_map into groupcompress order.
 

